If for example your app is so large that you are hitting, for example, the limits of GAE, you can switch on "dynamic module" compilation (pyjsbuild -m). This option will split your app into several shared javascript files, one per python module. It gives something like a 65% reduction in the size of the application cache files, across the five supported browsers (Opera, Safari, Netscape, Old Mozilla and IE). It's only just been added (to Pyjamas 0.5) so a) be advised b) watch this space.